+{
   entry => <<'ENTRY', # for DUCET v5.2.0
0063 0068 ; [.14AE.0020.0002.0063] # <LATIN SMALL LETTER C, LATIN SMALL LETTER H>
0043 0068 ; [.14AE.0020.0007.0043] # <LATIN CAPITAL LETTER C, LATIN SMALL LETTER H>
0043 0048 ; [.14AE.0020.0008.0043] # <LATIN CAPITAL LETTER C, LATIN CAPITAL LETTER H>
0064 0068 ; [.14AF.0020.0002.0064] # <LATIN SMALL LETTER D, LATIN SMALL LETTER H>
0044 0068 ; [.14AF.0020.0007.0044] # <LATIN CAPITAL LETTER D, LATIN SMALL LETTER H>
0044 0048 ; [.14AF.0020.0008.0044] # <LATIN CAPITAL LETTER D, LATIN CAPITAL LETTER H>
006B 0068 ; [.14B0.0020.0002.006B] # <LATIN SMALL LETTER K, LATIN SMALL LETTER H>
004B 0068 ; [.14B0.0020.0007.004B] # <LATIN CAPITAL LETTER K, LATIN SMALL LETTER H>
004B 0048 ; [.14B0.0020.0008.004B] # <LATIN CAPITAL LETTER K, LATIN CAPITAL LETTER H>
006E 0079 ; [.14B1.0020.0002.006E] # <LATIN SMALL LETTER N, LATIN SMALL LETTER Y>
004E 0079 ; [.14B1.0020.0007.004E] # <LATIN CAPITAL LETTER N, LATIN SMALL LETTER Y>
004E 0059 ; [.14B1.0020.0008.004E] # <LATIN CAPITAL LETTER N, LATIN CAPITAL LETTER Y>
0070 0068 ; [.14B2.0020.0002.0070] # <LATIN SMALL LETTER P, LATIN SMALL LETTER H>
0050 0068 ; [.14B2.0020.0007.0050] # <LATIN CAPITAL LETTER P, LATIN SMALL LETTER H>
0050 0048 ; [.14B2.0020.0008.0050] # <LATIN CAPITAL LETTER P, LATIN CAPITAL LETTER H>
0073 0068 ; [.14B3.0020.0002.0073] # <LATIN SMALL LETTER S, LATIN SMALL LETTER H>
0053 0068 ; [.14B3.0020.0007.0053] # <LATIN CAPITAL LETTER S, LATIN SMALL LETTER H>
ENTRY
};
