+{
   entry => <<'ENTRY', # for DUCET v5.2.0
00E1      ; [.1224.0020.0002.00E1] # LATIN SMALL LETTER A WITH ACUTE
0061 0301 ; [.1224.0020.0002.00E1] # LATIN SMALL LETTER A WITH ACUTE
0061 0341 ; [.1224.0020.0002.00E1] # LATIN SMALL LETTER A WITH ACUTE
00C1      ; [.1224.0020.0008.00C1] # LATIN CAPITAL LETTER A WITH ACUTE
0041 0301 ; [.1224.0020.0008.00C1] # LATIN CAPITAL LETTER A WITH ACUTE
0041 0341 ; [.1224.0020.0008.00C1] # LATIN CAPITAL LETTER A WITH ACUTE
0111      ; [.1250.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0064 0335 ; [.1250.0021.0002.0111] # LATIN SMALL LETTER D WITH STROKE
0110      ; [.1250.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
0044 0335 ; [.1250.0021.0008.0110] # LATIN CAPITAL LETTER D WITH STROKE
00F0      ; [.1251.0020.0002.00F0] # LATIN SMALL LETTER ETH
00D0      ; [.1251.0020.0008.00D0] # LATIN CAPITAL LETTER ETH
00E9      ; [.12A2.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
0065 0301 ; [.12A2.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
0065 0341 ; [.12A2.0020.0002.00E9] # LATIN SMALL LETTER E WITH ACUTE
00C9      ; [.12A2.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
0045 0301 ; [.12A2.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
0045 0341 ; [.12A2.0020.0008.00C9] # LATIN CAPITAL LETTER E WITH ACUTE
00ED      ; [.1304.0020.0002.00ED] # LATIN SMALL LETTER I WITH ACUTE
0069 0301 ; [.1304.0020.0002.00ED] # LATIN SMALL LETTER I WITH ACUTE
0069 0341 ; [.1304.0020.0002.00ED] # LATIN SMALL LETTER I WITH ACUTE
00CD      ; [.1304.0020.0008.00CD] # LATIN CAPITAL LETTER I WITH ACUTE
0049 0301 ; [.1304.0020.0008.00CD] # LATIN CAPITAL LETTER I WITH ACUTE
0049 0341 ; [.1304.0020.0008.00CD] # LATIN CAPITAL LETTER I WITH ACUTE
00F3      ; [.13B2.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
006F 0301 ; [.13B2.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
006F 0341 ; [.13B2.0020.0002.00F3] # LATIN SMALL LETTER O WITH ACUTE
00D3      ; [.13B2.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0301 ; [.13B2.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
004F 0341 ; [.13B2.0020.0008.00D3] # LATIN CAPITAL LETTER O WITH ACUTE
00FA      ; [.147A.0020.0002.00FA] # LATIN SMALL LETTER U WITH ACUTE
0075 0301 ; [.147A.0020.0002.00FA] # LATIN SMALL LETTER U WITH ACUTE
0075 0341 ; [.147A.0020.0002.00FA] # LATIN SMALL LETTER U WITH ACUTE
00DA      ; [.147A.0020.0008.00DA] # LATIN CAPITAL LETTER U WITH ACUTE
0055 0301 ; [.147A.0020.0008.00DA] # LATIN CAPITAL LETTER U WITH ACUTE
0055 0341 ; [.147A.0020.0008.00DA] # LATIN CAPITAL LETTER U WITH ACUTE
00FD      ; [.14AC.0020.0002.00FD] # LATIN SMALL LETTER Y WITH ACUTE
0079 0301 ; [.14AC.0020.0002.00FD] # LATIN SMALL LETTER Y WITH ACUTE
0079 0341 ; [.14AC.0020.0002.00FD] # LATIN SMALL LETTER Y WITH ACUTE
00DD      ; [.14AC.0020.0008.00DD] # LATIN CAPITAL LETTER Y WITH ACUTE
0059 0301 ; [.14AC.0020.0008.00DD] # LATIN CAPITAL LETTER Y WITH ACUTE
0059 0341 ; [.14AC.0020.0008.00DD] # LATIN CAPITAL LETTER Y WITH ACUTE
00E6      ; [.1522.0020.0002.00E6] # LATIN SMALL LETTER AE
00C6      ; [.1522.0020.0008.00C6] # LATIN CAPITAL LETTER AE
1D2D      ; [.1522.0020.0014.1D2D] # MODIFIER LETTER CAPITAL AE
01FD      ; [.1522.0020.0002.00E6][.0000.0032.0002.0301] # LATIN SMALL LETTER AE WITH ACUTE
01FC      ; [.1522.0020.0008.00C6][.0000.0032.0002.0301] # LATIN CAPITAL LETTER AE WITH ACUTE
01E3      ; [.1522.0020.0002.00E6][.0000.005B.0002.0304] # LATIN SMALL LETTER AE WITH MACRON
01E2      ; [.1522.0020.0008.00C6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER AE WITH MACRON
00E4      ; [.1522.0021.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
0061 0308 ; [.1522.0021.0002.00E4] # LATIN SMALL LETTER A WITH DIAERESIS
00C4      ; [.1522.0021.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
0041 0308 ; [.1522.0021.0008.00C4] # LATIN CAPITAL LETTER A WITH DIAERESIS
01DF      ; [.1522.0021.0002.00E4][.0000.005B.0002.0304] # LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
01DE      ; [.1522.0021.0008.00C4][.0000.005B.0002.0304] # LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
00F6      ; [.1523.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
006F 0308 ; [.1523.0020.0002.00F6] # LATIN SMALL LETTER O WITH DIAERESIS
00D6      ; [.1523.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
004F 0308 ; [.1523.0020.0008.00D6] # LATIN CAPITAL LETTER O WITH DIAERESIS
022B      ; [.1523.0020.0002.00F6][.0000.005B.0002.0304] # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
022A      ; [.1523.0020.0008.00D6][.0000.005B.0002.0304] # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
00F8      ; [.1523.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
006F 0338 ; [.1523.0021.0002.00F8] # LATIN SMALL LETTER O WITH STROKE
00D8      ; [.1523.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
004F 0338 ; [.1523.0021.0008.00D8] # LATIN CAPITAL LETTER O WITH STROKE
01FF      ; [.1523.0021.0002.00F8][.0000.0032.0002.0301] # LATIN SMALL LETTER O WITH STROKE AND ACUTE
01FE      ; [.1523.0021.0008.00D8][.0000.0032.0002.0301] # LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
00E5      ; [.1524.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
0061 030A ; [.1524.0020.0002.00E5] # LATIN SMALL LETTER A WITH RING ABOVE
00C5      ; [.1524.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
0041 030A ; [.1524.0020.0008.00C5] # LATIN CAPITAL LETTER A WITH RING ABOVE
212B      ; [.1524.0020.0008.00C5] # ANGSTROM SIGN
01FB      ; [.1524.0020.0002.00E5][.0000.0032.0002.0301] # LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
01FA      ; [.1524.0020.0008.00C5][.0000.0032.0002.0301] # LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
ENTRY
};
